==> Paws-0.02.tar.gz: Paws-0.02/lib/Paws/IAM/DetachRolePolicy.pm <==

package Paws::IAM::DetachRolePolicy {
  use Moose;
  has PolicyArn => (is => 'ro', isa => 'Str', required => 1);
  has RoleName => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DetachRolePolicy');
  class_has _returns => (isa => 'Str', is => 'ro');
  class_has _result_key => (isa => 'Str', is => 'ro');
}
1;

### main pod documentation begin ###

=head1 NAME

Paws::IAM::DetachRolePolicy - Arguments for method DetachRolePolicy on Paws::IAM

=head1 DESCRIPTION

This class represents the parameters used for calling the method DetachRolePolicy on the 
AWS Identity and Access Management service. Use the attributes of this class
as arguments to method DetachRolePolicy.

You shouln't make instances of this class. Each attribute should be used as a named argument in the call to DetachRolePolicy.

As an example:

  $service_obj->DetachRolePolicy(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES

=head2 B<REQUIRED> PolicyArn => Str

  

=head2 B<REQUIRED> RoleName => Str

  

The name (friendly name, not ARN) of the role to detach the policy
from.












=head1 SEE ALSO

This class forms part of L<Paws>, and documents parameters for DetachRolePolicy in Paws::IAM

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.11.tar.gz: Paws-0.11/lib/Paws/IAM/DetachRolePolicy.pm <==

package Paws::IAM::DetachRolePolicy {
  use Moose;
  has PolicyArn => (is => 'ro', isa => 'Str', required => 1);
  has RoleName => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DetachRolePolicy');
  class_has _returns => (isa => 'Str', is => 'ro');
  class_has _result_key => (isa => 'Str', is => 'ro');
}
1;

### main pod documentation begin ###

=head1 NAME

Paws::IAM::DetachRolePolicy - Arguments for method DetachRolePolicy on Paws::IAM

=head1 DESCRIPTION

This class represents the parameters used for calling the method DetachRolePolicy on the 
AWS Identity and Access Management service. Use the attributes of this class
as arguments to method DetachRolePolicy.

You shouln't make instances of this class. Each attribute should be used as a named argument in the call to DetachRolePolicy.

As an example:

  $service_obj->DetachRolePolicy(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES

=head2 B<REQUIRED> PolicyArn => Str

  

=head2 B<REQUIRED> RoleName => Str

  

The name (friendly name, not ARN) of the role to detach the policy
from.












=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DetachRolePolicy in L<Paws::IAM>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut
